@@ -35,6 +35,22 @@ var traversePathOperatorScenarios = []expressionScenario{
 			"D0, P[0 0], (!!int)::1\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `blah: {}`,
+		expression: `.blah.cat = "cool"`,
+		expected: []string{
+			"D0, P[], (doc)::blah:\n    cat: cool\n",
+		},
+	},
+	{
+		skipDoc:    true,
+		document:   `blah: []`,
+		expression: `.blah.0 = "cool"`,
+		expected: []string{
+			"D0, P[], (doc)::blah:\n    - cool\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `b: cat`,
